@@ -14,8 +14,7 @@ end
 
 WRMT::wiiremotes.each(){ |wiiremote|
 	wiiremote.open()
-	wiiremote.set_enabled(WRMT::FUNCTION_MOTION, true)
-	wiiremote.set_enabled(WRMT::FUNCTION_IR, true)
+	wiiremote.ir = true;
 }
 
 done = false
@@ -32,7 +31,7 @@ until done do
 			wiiremote[WRMT::DATA_IR2_SIZE],
 			wiiremote[WRMT::DATA_IR2_X],
 			wiiremote[WRMT::DATA_IR2_Y])
-		done = true if wiiremote.check_button_all(WRMT::MASK_BUTTON_A|WRMT::MASK_BUTTON_B)
+		done = true if wiiremote.check_button_all("AB")
 	end
 	sleep(0.03);
 end
