@@ -36,7 +36,7 @@ until done do
 			wiiremote[WRMT::DATA_LEDS] = led;
 		end
 
-		done = true if wiiremote.check_button_all(WRMT::MASK_BUTTON_A|WRMT::MASK_BUTTON_B)
+		done = true if wiiremote.check_button_all("AB")
 	end
 	sleep(0.03);
 end
