@@ -14,7 +14,7 @@ end
 
 WRMT::wiiremotes.each(){ |wiiremote|
 	wiiremote.open()
-	wiiremote.set_enabled(WRMT::FUNCTION_MOTION, true)
+	wiiremote.motion = true;
 }
 
 done = false
@@ -26,7 +26,7 @@ until done do
 			wiiremote[WRMT::DATA_MOTION_X],
 			wiiremote[WRMT::DATA_MOTION_Y],
 			wiiremote[WRMT::DATA_MOTION_Z])
-		done = true if wiiremote.check_button_all(WRMT::MASK_BUTTON_A|WRMT::MASK_BUTTON_B)
+		done = true if wiiremote.check_button_all("AB")
 	end
 	sleep(0.03);
 end
